@@ -403,8 +403,9 @@ QWidget *KPGDataTable::beginEdit(int nRow, int nCol, bool bReplace)
 {
     QWidget *pWidget = QTable::beginEdit(nRow, nCol, bReplace);
     if(pWidget != 0)
+    {
         m_bInplaceEditing = true;
-    
+    }
     setActions();
     return pWidget;
 }
@@ -1127,7 +1128,7 @@ int KPGDataTable::generateSerialPrimaryKeyValue(pqxx::work &pqxxXaction)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        KPGSqlDialog dlg(this, strSql, e.what());
+        KPGSqlDialog dlg(this, strSql, m_connectionInThread.connection()->toUnicode(e.what()));
         dlg.exec();
         throw;
     }
@@ -1167,7 +1168,7 @@ long KPGDataTable::generateBigSerialPrimaryKeyValue(pqxx::work &pqxxXaction)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        KPGSqlDialog dlg(this, strSql, e.what());
+        KPGSqlDialog dlg(this, strSql, m_connectionInThread.connection()->toUnicode(e.what()));
         dlg.exec();
         throw;
     }
@@ -1239,7 +1240,7 @@ void KPGDataTable::refreshRow()
         
         ((QWidget *) parent())->setCursor(KCursor::arrowCursor());
         kdDebug() << k_funcinfo "Exception: " <<  e.what() << endl;
-        KMessageBox::error(this, e.what());
+        KMessageBox::error(this, m_connectionInThread.connection()->toUnicode(e.what()));
         return;
     } 
 }
@@ -1325,7 +1326,7 @@ void KPGDataTable::loadLob(const KURL& url)
     {
         ((QWidget *) parent())->setCursor(KCursor::arrowCursor());
         kdDebug() << k_funcinfo "Exception: " <<  e.what() << endl;
-        KMessageBox::error(this, e.what());
+        KMessageBox::error(this, m_connectionInThread.connection()->toUnicode(e.what()));
         return;
     } 
 }
@@ -1367,7 +1368,7 @@ void KPGDataTable::saveLob(const KURL& url)
     {
         ((QWidget *) parent())->setCursor(KCursor::arrowCursor());
         kdDebug() << k_funcinfo "Exception: " <<  e.what() << endl;
-        KMessageBox::error(this, e.what());
+        KMessageBox::error(this, m_connectionInThread.connection()->toUnicode(e.what()));
         return;
     } 
 }
@@ -1388,16 +1389,17 @@ void KPGDataTable::editLobInEditor()
         return;
     }
     
-    QString strPrepStmtName("EB_" + KPGUtil::unspacedName(m_strNamespaceName) + "_" + KPGUtil::unspacedName(m_strTableName));
-    std::string stdstrPrepStmtName(strPrepStmtName.latin1());
-    
     try
     {
-        work pqxxXaction(*m_connectionInThread.connection(), stdstrPrepStmtName);
+        QString strPrepStmtNameS("EL1_" + KPGUtil::unspacedName(m_strNamespaceName) + "_" + KPGUtil::unspacedName(m_strTableName));
+        std::string stdstrPrepStmtNameS(strPrepStmtNameS.latin1());
         
-        pqxx::largeobject pqxxLargeObjectIn = getLargeObject(nRow, nCol, stdstrPrepStmtName, pqxxXaction);
+        work pqxxXaction(*m_connectionInThread.connection(), stdstrPrepStmtNameS);
+        
+        pqxx::largeobject pqxxLargeObjectIn = getLargeObject(nRow, nCol, stdstrPrepStmtNameS, pqxxXaction);
         largeobjectaccess pqxxLargeObjectAccessIn(pqxxXaction, pqxxLargeObjectIn, PGSTD::ios::in);
         
+        
         // Get LOB buffer size in MB from settings
         int iLobBufferSize = KPoGreView::configuration()->datatable()->lobBufferSize();
         
@@ -1451,7 +1453,10 @@ void KPGDataTable::editLobInEditor()
             
         pqxxLargeObjectAccessOut.write((std::string) m_connectionInThread.connection()->textCodec()->fromUnicode(strText));
         
-        if(setLargeObject(pqxxLargeObjectOut, nRow, nCol, stdstrPrepStmtName, pqxxXaction) == false)
+        QString strPrepStmtNameU("EL2_" + KPGUtil::unspacedName(m_strNamespaceName) + "_" + KPGUtil::unspacedName(m_strTableName));
+        std::string stdstrPrepStmtNameU(strPrepStmtNameU.latin1());
+        
+        if(setLargeObject(pqxxLargeObjectOut, nRow, nCol, stdstrPrepStmtNameU, pqxxXaction) == false)
         {
             pqxxXaction.abort();
             return;
@@ -1463,7 +1468,7 @@ void KPGDataTable::editLobInEditor()
     {
         ((QWidget *) parent())->setCursor(KCursor::arrowCursor());
         kdDebug() << k_funcinfo "Exception: " <<  e.what() << endl;
-        KMessageBox::error(this, e.what());
+        KMessageBox::error(this, m_connectionInThread.connection()->toUnicode(e.what()));
         return;
     } 
 }
@@ -1838,7 +1843,7 @@ bool KPGDataTable::runDml(EDmlType dmlType)
     {   
         ((QWidget *) parent())->setCursor(KCursor::arrowCursor());
         kdDebug() << k_funcinfo "Exception: " <<  e.what() << endl;
-        KMessageBox::error(this, e.what());
+        KMessageBox::error(this, m_connectionInThread.connection()->toUnicode(e.what()));
     }
      
     if(bNeedUnprepare)
@@ -1963,7 +1968,10 @@ pqxx::largeobject KPGDataTable::getLargeObject(int nRow, int nCol, std::string &
         else if((m_listTableColumns[nCol].typName() == "text") ||
                 (m_listTableColumns[nCol].typName() == "xml"))
         {
-            pqxxLargeObjectAccess << pqxxResult[0][0];
+            std::string charstring = pqxxResult[0][0].c_str();
+            long nBytes = pqxxLargeObjectAccess.cwrite(charstring.c_str(), charstring.size());
+            
+            kdDebug() << "Readed text size: " + to_string(nBytes) << endl;
         }
         
         return pqxxLargeObject;
