@@ -20,7 +20,6 @@
 class QBoxLayout;
 class KXMLGUIFactory;
 class KPoGreView;
-class KPGConnection;
 class KPGDataTable;
 class KPGKateXmlEditorDialog;
 
@@ -35,7 +34,7 @@ class KPGDataTableChildView : public KMdiChildView
 public:
     KPGDataTableChildView(KPoGreView *, 
 		KXMLGUIFactory *, 
-		KPGConnection *, 
+  		const PGSTD::string &, 
 		const QString&, 
 		const QString &, 
 		const ListTableColumns &,
