@@ -15,6 +15,7 @@
 #include <kdebug.h>
 
 #include "kpgaggregatesfolder.h"
+#include "kpgconnection.h"
 
 KPGAggregate::KPGAggregate(KPGAggregatesFolder *parent, const QString name)
   : KPGTreeItem(parent, name)
@@ -32,7 +33,8 @@ KPGAggregate::~KPGAggregate()
 {
 }
 
-void KPGAggregate::setProperties(const pqxx::result::tuple &pqxxTuple)
+void KPGAggregate::setProperties(const pqxx::result::tuple &pqxxTuple,
+								 const KPGConnection *pConnection)
 {
 	pqxxTuple["aggegfnoid"].to(m_oidAggregateFn);
 	pqxxTuple["aggtransfnoid"].to(m_oidTransFn);
@@ -41,7 +43,7 @@ void KPGAggregate::setProperties(const pqxx::result::tuple &pqxxTuple)
 	pqxxTuple["transtypoid"].to(m_oidTransType);
 	pqxxTuple["returntypoid"].to(m_oidRetType);
 		
-	m_strDescription = pqxxTuple["description"].c_str();
+	m_strDescription = pConnection->toUnicode(pqxxTuple["description"].c_str());
 	m_strAggregateFn = pqxxTuple["aggfnname"].c_str();
 	m_strOwner = pqxxTuple["aggrowner"].c_str();
 	m_strTransFn = pqxxTuple["aggtransfn"].c_str();
