@@ -46,9 +46,10 @@ void KPGCastsFolder::refresh() throw(const KPGSqlException &)
 	strQuery.append("LEFT JOIN pg_catalog.pg_namespace na ON na.oid=pr.pronamespace ");
 	strQuery.append("ORDER BY st.typname, tt.typname");
 		
+    KPGConnection *pConnection = connection();
 	try
     {
-        m_pqxxResultCasts = connection()->runQuery(strQuery);
+        m_pqxxResultCasts = pConnection->runQuery(strQuery);
     
         KPGCast *pCast = 0;
             
@@ -68,7 +69,7 @@ void KPGCastsFolder::refresh() throw(const KPGSqlException &)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
     } 
 }
 
