@@ -46,9 +46,10 @@ void KPGConversionsFolder::refresh() throw(const KPGSqlException &)
 	strQuery.append("WHERE connamespace = " + QString("%1").arg(m_oidNameSpace) + " ");
 	strQuery.append("ORDER BY conname");
 			
+    KPGConnection *pConnection = connection();
     try
     {
-        m_pqxxResultConversions = connection()->runQuery(strQuery);
+        m_pqxxResultConversions = pConnection->runQuery(strQuery);
     
         KPGConversion *pConversion = 0;
             
@@ -68,6 +69,6 @@ void KPGConversionsFolder::refresh() throw(const KPGSqlException &)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
     } 
 }
