@@ -16,6 +16,7 @@
 #include <klocale.h>
 
 #include "kpgdomainconstraintsfolder.h"
+#include "kpgconnection.h"
 
 
 KPGDomainConstraint::KPGDomainConstraint(KPGDomainConstraintsFolder *parent, const QString name, pqxx::oid _oid)
@@ -34,9 +35,10 @@ KPGDomainConstraint::~KPGDomainConstraint()
 {
 }
 
-void KPGDomainConstraint::setProperties(const pqxx::result::tuple &pqxxTuple)
+void KPGDomainConstraint::setProperties(const pqxx::result::tuple &pqxxTuple,
+										const KPGConnection *pConnection)
 {
-    m_strDescription = pqxxTuple["description"].c_str();
+	m_strDescription = pConnection->toUnicode(pqxxTuple["description"].c_str());
     m_strExpression = pqxxTuple["consrc"].c_str();
     m_strNspName = pqxxTuple["nspname"].c_str();
 }
