@@ -34,7 +34,7 @@ public:
     // Get SQL object type 
   	virtual const char * getObjectType() const { return "DOMAIN CONSTRAINT"; }
     
-    void setProperties(const pqxx::result::tuple &);
+	void setProperties(const pqxx::result::tuple &, const KPGConnection *pConnection);
         
     // Refresh item, ald also childs objects
 	void refresh() throw(const KPGSqlException &) { return; }
