@@ -28,27 +28,45 @@ class KPGFunctionsFolder;
 class KPGFunctionArgument
 {
 public:
+    
+    // Argument mode
+    enum EMode 
+    { 	
+        input = 0,
+        output,
+        inout,
+        unknown
+    };
+    
 	KPGFunctionArgument() {;}
-	KPGFunctionArgument(unsigned int iSequence, const QString & strName, const QString & strMode, const QString & strTypName)
-	{
-		m_iSequence = iSequence;
-		m_strName = strName;
-		m_strMode = strMode;
-		m_strTypName = strTypName;
-	}
-
-	const unsigned int sequence() const { return m_iSequence; }
+	KPGFunctionArgument(unsigned int, const QString &, const QString &, const QString &);
+    KPGFunctionArgument(unsigned int, const QString &, EMode, const QString &);
+    
+	unsigned int sequence() const { return m_iSequence; }
 	const QString &name() const { return m_strName; }
-	const QString &mode() const { return m_strMode; }
+    EMode mode() const { return m_eMode; }
 	const QString &typName() const { return m_strTypName; }
+    
+    const QString modeAsString() const 
+    { 
+        switch(m_eMode)
+        {
+            case input: return "IN";
+            case output: return "OUT";
+            case inout: return "INOUT";
+            default: return "UNKNOWN";
+        }
+    }
 
 protected:
 	unsigned int m_iSequence; // Starts from 1
 	QString m_strName;
-	QString m_strMode;
+    EMode m_eMode;
 	QString m_strTypName;
 };
 
+typedef QValueList<KPGFunctionArgument> ListFunctionArguments;
+
 /**
   * Function argument vith value
   *
@@ -63,6 +81,12 @@ public:
 	{
 		m_strValue = strValue;
 	}
+    
+    KPGFunctionArgumentWithValue(unsigned int iSequence, const QString & strName, EMode eMode, const QString & strTypName, const QString & strValue)
+    : KPGFunctionArgument(iSequence, strName, eMode, strTypName) 
+    {
+        m_strValue = strValue;
+    }
 	
 	const QString &value() const { return m_strValue; }
 
@@ -70,7 +94,7 @@ protected:
 	QString m_strValue;
 };
 
-typedef QValueList<KPGFunctionArgumentWithValue> ListArgumentsWithValues;
+typedef QValueList<KPGFunctionArgumentWithValue> ListFunctionArgumentsWithValues;
 
 
 /**
@@ -85,16 +109,14 @@ public:
 	KPGFunction(KPGFunctionsFolder *, KPGFunction *, const QString, pqxx::oid);
     ~KPGFunction();
 
-	typedef QValueList<KPGFunctionArgument> ListArguments;
-
 	virtual eNodeType type() const { return nodeFunction; }
 		
 	// Get SQL object type 
   	virtual const char * getObjectType() const { return "FUNCTION"; }
   	
-	void setProperties(const pqxx::result::tuple &);
+	void setProperties(const pqxx::result::tuple &, const KPGConnection *pConnection);
 	void setArgTypes(const QString strArgTypes) { m_strArgTypes = strArgTypes; }
-	void setSrc(const QString &strSrc) { m_strSrc = strSrc; }
+	void setSourceCode(const QString &strSourceCode);
 	void setListArguments(const QString &, const QString &, const QString &, const QString &);
 	
 	// Refresh item, ald also childs objects
@@ -111,11 +133,11 @@ public:
 	bool isStrict() const { return m_bIsStrict; }
 	bool returnSet() const { return m_bReturnSet; }
 	const QString & getVolatile() const { return m_strVolatile; }
-	int nArgs() const { return m_iNArgs; }
+	unsigned int nArgs() const { return m_uiNArgs; }
 	const QString & bin() const { return m_strBin; }
 	const QString langName() const { return m_strLanName; }
 	const QString & argTypes() const { return  m_strArgTypes; }
-	const QString & source() const { return m_strSrc; }
+	const QString & sourceCode() const { return m_strSourceCode; }
 	const QString & returnTypName() const { return m_strReturnTypName; }
 	pqxx::oid oidReturnType() const { return m_oidReturnType; }
 	const QString & acl() const { return m_strACL; }
@@ -131,7 +153,7 @@ public:
     const QString nameWithArguments() const;
     
     // Get list of arguments
-    const KPGFunction::ListArguments & listArguments() const { return m_listArguments; }
+    const ListFunctionArguments & listArguments() const { return m_listArguments; }
     
 protected:
 	
@@ -143,7 +165,7 @@ protected:
 	bool m_bIsStrict;
 	bool m_bReturnSet;
 	QString m_strVolatile;
-	int m_iNArgs;
+	unsigned int m_uiNArgs;
 	QString m_strBin;
 	QString m_strACL;
 	pqxx::oid m_oidReturnType;
@@ -155,10 +177,10 @@ protected:
 	QString m_strArgTypes;
 	
 	// It might be the actual source code of the function for interpreted languages, a link symbol, a file name, or just about anything else, depending on the implementation language/call convention.
-	QString m_strSrc;
+	QString m_strSourceCode;
 	
 	// List of argument informations, available since PostgreSQL 8.1
-	ListArguments m_listArguments;
+    ListFunctionArguments m_listArguments;
 };
 
 #endif
