@@ -38,9 +38,10 @@ void KPGGroupsFolder::refresh() throw(const KPGSqlException &)
         // obtain list of tables
     QString strQuery("SELECT groname, grosysid FROM pg_catalog.pg_group ORDER BY groname;");
                 
+    KPGConnection *pConnection = connection();
     try
     {
-        m_pqxxResultGroups = connection()->runQuery(strQuery);
+        m_pqxxResultGroups = pConnection->runQuery(strQuery);
     
         KPGGroup *pGroup = 0;
             
@@ -81,6 +82,6 @@ void KPGGroupsFolder::refresh() throw(const KPGSqlException &)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
     } 
 }
