@@ -43,9 +43,10 @@ void KPGLanguagesFolder::refresh() throw(const KPGSqlException &)
 	strQuery.append("WHERE lanispl IS TRUE ");
 	strQuery.append("ORDER BY lanname");
 			
+    KPGConnection *pConnection = connection();
     try
     {
-        m_pqxxResultLanguages = connection()->runQuery(strQuery);
+        m_pqxxResultLanguages = pConnection->runQuery(strQuery);
     
         KPGLanguage *pLanguage = 0;
             
@@ -65,7 +66,7 @@ void KPGLanguagesFolder::refresh() throw(const KPGSqlException &)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
     } 
 }
 
