@@ -68,9 +68,10 @@ void KPGOperatorClassesFolder::refresh() throw(const KPGSqlException &)
 	strQuery.append("WHERE opcnamespace = " + QString("%1").arg(m_oidNameSpace) + " ");
 	strQuery.append("ORDER BY op.opcname");
 			
+    KPGConnection *pConnection = connection();
     try
     {
-        m_pqxxResultOperatorClasses = connection()->runQuery(strQuery);
+        m_pqxxResultOperatorClasses = pConnection->runQuery(strQuery);
     
         KPGOperatorClass *pOperatorClass = 0;
             
@@ -90,6 +91,6 @@ void KPGOperatorClassesFolder::refresh() throw(const KPGSqlException &)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
     } 
 }
