@@ -53,10 +53,10 @@ void KPGRule::refreshItem() throw(const KPGSqlException &)
 	strQuery.append(" AND rw.oid=");
 	strQuery.append(QString("%1").arg(m_oid));
 	
+    KPGConnection *pConnection = connection();
 	try
 	{
-		KPGConnection *pConnection = connection();
-		pqxx::result pqxxResultRules = pConnection->runQuery(strQuery);
+        pqxx::result pqxxResultRules = pConnection->runQuery(strQuery);
 
 		if(pqxxResultRules.size() != 1)
 		{
@@ -64,12 +64,12 @@ void KPGRule::refreshItem() throw(const KPGSqlException &)
 			return;
 		}
 		
-		setProperties(pqxxResultRules[0], pConnection);
+        setProperties(pqxxResultRules[0], connection());
 	}
 	catch (const std::exception &e)
 	{
 		kdError() << k_funcinfo << e.what() << endl;
-		throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
 	} 
 }
 
