@@ -98,7 +98,7 @@ void KPGSchema::activate()
 		catch (const KPGSqlException &e)
 		{
 			listView()->setCursor(KCursor::arrowCursor());
-			KPGSqlDialog dlg(0, e.getSql(), e.what());
+			KPGSqlDialog dlg(0, e.sql(), e.message());
 			dlg.exec();
 		}
 		listView()->setCursor(KCursor::arrowCursor());
@@ -143,10 +143,10 @@ void KPGSchema::refreshItem() throw(const KPGSqlException &)
     
     strQuery.append("WHERE nsp.oid = " + QString("%1").arg(m_oid));
         
+    KPGConnection *pConnection = connection();
     try
     {
-		KPGConnection *pConnection = connection();
-        pqxx::result pqxxResultSchemas = pConnection->runQuery(strQuery);
+		pqxx::result pqxxResultSchemas = pConnection->runQuery(strQuery);
     
         if(pqxxResultSchemas.size() != 1)
         {
@@ -159,7 +159,7 @@ void KPGSchema::refreshItem() throw(const KPGSqlException &)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
     } 
 }
 
