@@ -101,10 +101,10 @@ void KPGSequence::refreshItem() throw(const KPGSqlException &)
     
     strQuery.append("WHERE cl.oid = " + QString("%1").arg(m_oid));
         
+    KPGConnection *pConnection = connection();
     try
     {
-		KPGConnection *pConnection = connection();
-        pqxx::result pqxxResultSequences = pConnection->runQuery(strQuery);
+		pqxx::result pqxxResultSequences = pConnection->runQuery(strQuery);
     
         if(pqxxResultSequences.size() != 1)
         {
@@ -130,7 +130,7 @@ void KPGSequence::refreshItem() throw(const KPGSqlException &)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
     } 
 }
 
@@ -139,15 +139,15 @@ const pqxx::result KPGSequence::queryIoStatistics() throw(const KPGSqlException
 	QString strQuery("SELECT relname, blks_read, blks_hit FROM pg_catalog.pg_statio_all_sequences WHERE relid = ");
     strQuery.append(QString("%1;").arg(m_oid));
     
+    KPGConnection *pConnection = connection();
     try
     {
-        KPGConnection *pDbConnection = connection();
-        pqxx::work pqxxXaction(*pDbConnection, "refresh sequence statistics");
+        pqxx::work pqxxXaction(*pConnection, "refresh sequence statistics");
         return pqxxXaction.exec(strQuery.latin1());
     }
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
     } 
 }
