@@ -12,7 +12,7 @@
 #ifndef KPGTABLEITEMSFOLDER_H
 #define KPGTABLEITEMSFOLDER_H
 
-#include "kpgtreeitem.h"
+#include "kpgitemsfolder.h"
 
 #include "kpgtable.h"
 
@@ -26,11 +26,11 @@ class KComboBox;
   *
   * @author Lumir Vanek
   */
-class KPGTableItemsFolder : public KPGTreeItem
+class KPGTableItemsFolder : public KPGItemsFolder
 {
 public:
-    KPGTableItemsFolder(KPGTable *, const QString &);
-	KPGTableItemsFolder(KPGTable *, KPGTableItemsFolder *, const QString &);
+	KPGTableItemsFolder(KPGTable *, const QString &, QPixmap *, QPixmap *);
+	KPGTableItemsFolder(KPGTable *, KPGTableItemsFolder *, const QString &, QPixmap *, QPixmap *);
     ~KPGTableItemsFolder();
 
 	virtual void activate();
@@ -40,9 +40,9 @@ public:
 	
 	virtual void refresh(pqxx::oid) throw(const KPGSqlException &) = 0;
 	    
-    void fillListBoxWithChildItems(QListBox *);
-    void fillListBoxWithChildItems(KListBox *);
-    void fillComboBoxWithChildItems(KComboBox *);
+    //void fillListBoxWithChildItems(QListBox *);
+    //void fillListBoxWithChildItems(KListBox *);
+    //void fillComboBoxWithChildItems(KComboBox *);
 		
 protected:
 
