@@ -53,11 +53,12 @@ void KPGTablespacesFolder::refresh() throw(const KPGSqlException &)
 	}
 	
 	strQuery.append("FROM pg_catalog.pg_tablespace ts ");
-	strQuery.append("LEFT JOIN pg_catalog.pg_shadow sh ON ts.spcowner=sh.usesysid  ");
+    strQuery.append("LEFT JOIN pg_catalog.pg_user sh ON ts.spcowner=sh.usesysid  ");
 			
+    KPGConnection *pConnection = connection();
 	try
 	{
-		m_pqxxResultTablespaces = connection()->runQuery(strQuery);
+        m_pqxxResultTablespaces = pConnection->runQuery(strQuery);
 	
 		KPGTablespace *pTablespace = 0;
 			
@@ -77,6 +78,6 @@ void KPGTablespacesFolder::refresh() throw(const KPGSqlException &)
 	catch (const std::exception &e)
 	{
 		kdError() << k_funcinfo << e.what() << endl;
-		throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
 	} 
 }
