@@ -24,6 +24,7 @@
 #include <qlistview.h>
 
 // include files for libpgxx 
+#define PQXX_ALLOW_LONG_LONG
 #include <pqxx/transaction> 
 #include <pqxx/result> 
 
@@ -306,7 +307,7 @@ public:
     
 	
 	// Return PostgreSQL row identifier
-	const pqxx::oid oid() const { return m_oid; }
+	pqxx::oid oid() const { return m_oid; }
 		
 	// Return name
 	const QString & name() const { return m_strName; }
@@ -327,7 +328,7 @@ public:
 	const QString & description() const { return m_strDescription; }
 		
 	// Return PostgreSQL row identifier of underlying type
-	const pqxx::oid oidUnderlyingType() const { return m_oidUnderlyingType; }
+	pqxx::oid oidUnderlyingType() const { return m_oidUnderlyingType; }
 	
 	// Set underlying type OID
 	void setOidUnderlyingType(pqxx::oid oidUnderlyingType) { m_oidUnderlyingType = oidUnderlyingType; }
@@ -414,6 +415,7 @@ public:
 	{
 	}
 	
+	// An assignment operator
 	void operator = (const KPGOidNameAliases &src)
 	{
 		KPGOidName::operator = (src);
