@@ -55,9 +55,9 @@ void KPGTrigger::refreshItem() throw(const KPGSqlException &)
 	strQuery.append(" AND t.oid=");
 	strQuery.append(QString("%1").arg(m_oid));
 	
-	try
+    KPGConnection *pConnection = connection();
+    try
 	{
-		KPGConnection *pConnection = connection();
 		pqxx::result pqxxResultTriggers = pConnection->runQuery(strQuery);
 
 		if(pqxxResultTriggers.size() != 1)
@@ -72,7 +72,7 @@ void KPGTrigger::refreshItem() throw(const KPGSqlException &)
 	catch (const std::exception &e)
 	{
 		kdError() << k_funcinfo << e.what() << endl;
-		throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
 	} 
 }
 
