@@ -16,7 +16,7 @@
 #include <klocale.h>
 
 #include "kpgtype.h"
-
+#include "kpgconnection.h"
 
 KPGTypeAttribute::KPGTypeAttribute(KPGType *parent, const QString name)
   : KPGTreeItem(parent, name)
@@ -36,7 +36,8 @@ KPGTypeAttribute::~KPGTypeAttribute()
 {
 }
 
-void KPGTypeAttribute::setProperties(const pqxx::result::tuple &pqxxTuple)
+void KPGTypeAttribute::setProperties(const pqxx::result::tuple &pqxxTuple,
+									 const KPGConnection *pConnection)
 {
 	pqxxTuple["atttypid"].to(m_oidType);
 	pqxxTuple["attlen"].to(m_iAttLen);
@@ -46,7 +47,7 @@ void KPGTypeAttribute::setProperties(const pqxx::result::tuple &pqxxTuple)
 			
 	m_strTypName = pqxxTuple["typname"].c_str();
 	m_strNspName = pqxxTuple["nspname"].c_str();
-	m_strDescription = pqxxTuple["description"].c_str();
+	m_strDescription = pConnection->toUnicode(pqxxTuple["description"].c_str());
 
 	//--- Set column type icon ---------------------------------------------------
 	if((m_strTypName == "bpchar") || (m_strTypName == "varchar") || (m_strTypName == "text"))
