@@ -29,7 +29,7 @@ public:
   	~KPGTypeAttribute();
   
 	virtual eNodeType type() const { return nodeTypeAttribute; }
-  	void setProperties(const pqxx::result::tuple &);
+	void setProperties(const pqxx::result::tuple &, const KPGConnection *pConnection);
   	
   	// Refresh item, ald also childs objects
 	void refresh() throw(const KPGSqlException &) { return refreshItem(); }
