@@ -36,14 +36,15 @@ void KPGUsersFolder::refresh() throw(const KPGSqlException &)
     while (QListViewItem * pItem = firstChild())
         delete pItem;
     
-        // obtain list of users
+    // obtain list of users
     QString strQuery("SELECT usesysid, usename, usecreatedb, usesuper, usecatupd, valuntil FROM ");
     strQuery.append("pg_catalog.pg_user u "); // or pg_shadow
     strQuery.append("ORDER BY usename");
                 
+    KPGConnection *pConnection = connection();
     try
     {
-        m_pqxxResultUsers = connection()->runQuery(strQuery);
+        m_pqxxResultUsers = pConnection->runQuery(strQuery);
     
         KPGUser *pUser = 0;
             
@@ -60,6 +61,6 @@ void KPGUsersFolder::refresh() throw(const KPGSqlException &)
     catch (const std::exception &e)
     {
         kdError() << k_funcinfo << e.what() << endl;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
     } 
 }
