@@ -65,9 +65,9 @@ void KPGView::refreshItem() throw(const KPGSqlException &)
 	
 	strQuery.append("WHERE c.oid = " + QString("%1").arg(m_oid));
 		
-	try
+    KPGConnection *pConnection = connection();
+    try
 	{
-		KPGConnection *pConnection = connection();
 		pqxx::result pqxxResultViews = pConnection->runQuery(strQuery);
 	
 		if(pqxxResultViews.size() != 1)
@@ -87,7 +87,7 @@ void KPGView::refreshItem() throw(const KPGSqlException &)
 	catch (const std::exception &e)
 	{
 		kdError() << k_funcinfo << e.what() << endl;
-		throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(pConnection, e.what(), strQuery);
 	} 
 }
 
