@@ -813,7 +813,7 @@ void KPGDebugger::executeFunction()
 		}
 		catch(const std::exception &e)
 		{
-			m_pTextEditResult->append(e.what());
+            m_pTextEditResult->append(m_connInThreadFunction.connection()->toUnicode(e.what()));
             m_pTabWidget->setCurrentPage(TAB_PAGE_RESULT_TABLE);
 	
 			return;
