@@ -31,7 +31,9 @@ KPGDebuggerChildView::KPGDebuggerChildView(KPoGreView *pPoGreView,
 	KXMLGUIFactory * pXmlGuiFactory,
  	const PGSTD::string& strConnectionOptions,
 	const QString & strNamespace, 
-	KPGFunction *pFunction
+	KPGFunction *pFunction,
+ 	const QString& strServerName,
+	pqxx::oid oidDatabase
 	)
  : KMdiChildView(i18n("Debugger"), pPoGreView, "KPGExecutorChildView")
 {
@@ -44,7 +46,9 @@ KPGDebuggerChildView::KPGDebuggerChildView(KPoGreView *pPoGreView,
 		pXmlGuiFactory,
   		strConnectionOptions, 
 		strNamespace, 
-		pFunction);
+		pFunction,
+  		strServerName,
+  		oidDatabase);
 
 	pLayout->addWidget(m_pDebugger);
 	
@@ -72,6 +76,12 @@ void KPGDebuggerChildView::slotDeactivated()
 
 bool KPGDebuggerChildView::requestClose()
 {
+    if(m_pDebugger->running())
+    {
+        KMessageBox::sorry(this, i18n("Debugger is running, cannot close !"));
+        return false;
+    }
+    
 	if(KMessageBox::questionYesNo(this, i18n("Really close debugger window ?")) == KMessageBox::Yes) 
 	{
 		return true;
