@@ -25,7 +25,7 @@ class KPGFunction;
 
 
 /**
-  * MDI child window for PL/pgSQL debugger (not implemented yet ...)
+  * MDI child window for PL/pgSQL debugger
   *
   * @author Lumir Vanek <lvanek@users.sourceforge.net>
   */
@@ -33,7 +33,7 @@ class KPGDebuggerChildView : public KMdiChildView
 {
 	Q_OBJECT
 public:
-	KPGDebuggerChildView(KPoGreView *, KParts::Factory *, KXMLGUIFactory *, const PGSTD::string& , const QString &, KPGFunction *);
+	KPGDebuggerChildView(KPoGreView *, KParts::Factory *, KXMLGUIFactory *, const PGSTD::string& , const QString &, KPGFunction *, const QString& , pqxx::oid);
     ~KPGDebuggerChildView();
 
     KPGDebugger* getDebugger() const { return m_pDebugger; }
