@@ -230,10 +230,9 @@ void KPGDebuggingThread::run()
     }
     catch (const KPGSqlException &e)
     {
-        kdError() << k_funcinfo  << endl << e.what() << endl;
+        kdError() << k_funcinfo  << endl << e.message() << endl;
         
-        QTextCodec *pTextCodec = QTextCodec::codecForLocale(); 
-        QApplication::postEvent(m_pEventReceiver, new KPGDebugEventError(pTextCodec->toUnicode(e.what())));
+        QApplication::postEvent(m_pEventReceiver, new KPGDebugEventError(e.message()));
         unlockMutex();
     }
     cleanup();
@@ -643,7 +642,7 @@ void KPGDebuggingThread::setBreakpoint(pqxx::oid oidFunction,
     {
         kdError() << k_funcinfo  << endl << e.what() << endl;
         m_state = failed;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(m_pConnectionDebugger, e.what(), strQuery);
     }
 }
 
@@ -696,7 +695,7 @@ void KPGDebuggingThread::dropBreakpoint(pqxx::oid oidFunction,
     {
         kdError() << k_funcinfo  << endl << e.what() << endl;
         m_state = failed;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(m_pConnectionDebugger, e.what(), strQuery);
     }
 }
 
@@ -742,7 +741,7 @@ void KPGDebuggingThread::depositValue() throw(const KPGSqlException &)
     {
         kdError() << k_funcinfo  << endl << e.what() << endl;
         m_state = failed;
-        throw KPGSqlException(e.what(), strQuery);
+        throw KPGSqlException(m_pConnectionDebugger, e.what(), strQuery);
     }
 }
 
