@@ -178,7 +178,7 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 	catch (const std::exception &e)
 	{
 		kdError() << "Failed to open connection " << e.what() << endl;
-		KMessageBox::sorry(this, e.what());
+        KMessageBox::sorry(this, m_connectionInThread.connection()->toUnicode(e.what()));
 		return;
 	}
 }
@@ -468,7 +468,7 @@ void KPGExecutor::stopExecute()
 		catch (const std::exception &e)
 		{
 			kdError() << "Failed to open connection " << e.what() << endl;
-			KMessageBox::sorry(this, e.what());
+            KMessageBox::sorry(this, m_connectionInThread.connection()->toUnicode(e.what()));
 			return;
 		}
 
@@ -717,7 +717,7 @@ bool KPGExecutor::runSql(KPGConnection::ETransType transType)
 		}
 		catch(const std::exception &e)
 		{
-			m_pTextEditResult->append(e.what());
+            m_pTextEditResult->append(m_connectionInThread.connection()->toUnicode(e.what()));
 			m_pTabWidget->setCurrentPage(1);
 	
 			return false;
