@@ -14,12 +14,12 @@
 
 #include <kmdichildview.h>
 
+#include "kpgexecutor.h"
+
 class KXMLGUIFactory;
 
 class QBoxLayout;
 class KPoGreView;
-class KPGExecutor;
-class KPGConnection;
 class KPGFunction;
 
 /**
@@ -31,7 +31,7 @@ class KPGExecutorChildView : public KMdiChildView
 {
 	Q_OBJECT
 public:
-    KPGExecutorChildView(KPoGreView *, KXMLGUIFactory * pXmlGuiFactory, KPGConnection *, const QString &, KPGFunction *);
+	KPGExecutorChildView(KPoGreView *, KXMLGUIFactory *, const PGSTD::string &, const QString &, KPGFunction *);
     ~KPGExecutorChildView();
 
 	KPGExecutor* getExecutor() const { return m_pExecutor; }
