@@ -17,6 +17,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgaggregatesfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 KPGAggregatesFolderPropPage::KPGAggregatesFolderPropPage(QWidget* parent, KPGAggregatesFolder * pAggregatesFolder)
 	: KPGPropertyPage(parent, "KPGAggregatesFolderPropPage")
@@ -48,7 +49,9 @@ void KPGAggregatesFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Return type"));
 	pHeader->setLabel(nCol++, i18n("Initial value"));
 	
-	KPGUtil::fillPropertiesTable(m_pAggregatesFolder->resultAggregates(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pAggregatesFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pAggregatesFolder->resultAggregates(), m_pTableItems, pTextCodec);
 }
 
 
