@@ -17,6 +17,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgcastsfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 KPGCastsFolderPropPage::KPGCastsFolderPropPage(QWidget *pParent, KPGCastsFolder *pCastsFolder)
  : KPGPropertyPage(pParent, "KPGCastsFolderPropPage")
@@ -44,6 +45,8 @@ void KPGCastsFolderPropPage::displayProperties()
   	pHeader->setLabel(nCol++, i18n("Function"));
 	pHeader->setLabel(nCol++, i18n("Namespace"));
 	
-	KPGUtil::fillPropertiesTable(m_pCastsFolder->resultCasts(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pCastsFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pCastsFolder->resultCasts(), m_pTableItems, pTextCodec);
 }
 
