@@ -17,6 +17,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgconversionsfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 KPGConversionsFolderPropPage::KPGConversionsFolderPropPage(QWidget *pParent, KPGConversionsFolder *pConversionsFolder)
  : KPGPropertyPage(pParent, "KPGConversionsFolderPropPage")
@@ -44,6 +45,8 @@ void KPGConversionsFolderPropPage::displayProperties()
  	pHeader->setLabel(nCol++, i18n("Conversion procedure"));
 	pHeader->setLabel(nCol++, i18n("Owner"));
 
-	KPGUtil::fillPropertiesTable(m_pConversionsFolder->resultConversions(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pConversionsFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pConversionsFolder->resultConversions(), m_pTableItems, pTextCodec);
 }
 
