@@ -19,6 +19,7 @@
 #include "../DbObjects/kpgtreeitem.h"
 
 // include files for Qt
+#include <qtextcodec.h>
 #include <qiconset.h>
 #include <qtable.h> 
 
@@ -256,7 +257,7 @@ void KPGDatabasePropPage::displayStatistics()
     {
         setCursor(KCursor::arrowCursor());
 		kdError() << k_funcinfo << e.what() << endl;
-		KPGSqlDialog dlg(this, strQuery, e.what());
+        KPGSqlDialog dlg(this, strQuery, m_pDatabase->connection()->toUnicode(e.what()));
 		dlg.exec();
 		return;
     } 
@@ -303,7 +304,7 @@ void KPGDatabasePropPage::displayExtendedStatistics(QTextCodec * pTextCodec)
 	{
 		setCursor(KCursor::arrowCursor());
 		kdError() << k_funcinfo << e.what() << endl;
-		KPGSqlDialog dlg(this, strQuery, e.what());
+        KPGSqlDialog dlg(this, strQuery, pTextCodec->toUnicode(e.what()));
 		dlg.exec();
 		return;
 	}
@@ -337,7 +338,7 @@ void KPGDatabasePropPage::slotRefreshLocks()
 	{
 		setCursor(KCursor::arrowCursor());
 		kdError() << k_funcinfo << e.what() << endl;
-		KPGSqlDialog dlg(this, strQuery, e.what());
+        KPGSqlDialog dlg(this, strQuery, m_pDatabase->connection()->toUnicode(e.what()));
 		dlg.exec();
 		return;
 	} 
@@ -372,7 +373,7 @@ void KPGDatabasePropPage::slotRefreshDiskUsage()
 	{
 		setCursor(KCursor::arrowCursor());
 		kdError() << k_funcinfo << e.what() << endl;
-		KPGSqlDialog dlg(this, strQuery, e.what());
+        KPGSqlDialog dlg(this, strQuery, m_pDatabase->connection()->toUnicode(e.what()));
 		dlg.exec();
 		return;
 	} 
