@@ -88,7 +88,7 @@ protected slots:
     virtual void slotUpdateACL();
  
 signals:
-	void sigSearchObject(const pqxx::oid);
+	void sigSearchObject(pqxx::oid);
     void sigRunWizard(const QString &); 
                 
     // Emit request for context menu for property table
