@@ -19,6 +19,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgdomainconstraintsfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 
 KPGDomainConstrFolderPropPage::KPGDomainConstrFolderPropPage(QWidget *pParent, KPGDomainConstraintsFolder *pDomainConstraintsFolder)
@@ -46,6 +47,8 @@ void KPGDomainConstrFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Description"));
 	pHeader->setLabel(nCol++, i18n("Namespace"));
 	
-	KPGUtil::fillPropertiesTable(m_pDomainConstraintsFolder->resultConstraints(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pDomainConstraintsFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pDomainConstraintsFolder->resultConstraints(), m_pTableItems, pTextCodec);
 }
 
