@@ -18,6 +18,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgdomainsfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 KPGDomainsFolderPropPage::KPGDomainsFolderPropPage(QWidget *pParent, KPGDomainsFolder *pDomainsFolder)
  : KPGPropertyPage(pParent, "KPGDomainsFolderPropPage")
@@ -45,5 +46,7 @@ void KPGDomainsFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Array delimiter"));
 	pHeader->setLabel(nCol++, i18n("Owner"));
 	
-    KPGUtil::fillPropertiesTable(m_pDomainsFolder->resultDomains(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pDomainsFolder->connection()->textCodec();
+	
+    KPGUtil::fillPropertiesTable(m_pDomainsFolder->resultDomains(), m_pTableItems, pTextCodec);
 }
