@@ -155,7 +155,7 @@ void KPGFunctionPropPage::displayProperties()
 	}
 	
 	m_pLineEditArgTypes->setText(m_pFunction->argTypes());
-	m_pTextEditSource->setText(m_pFunction->source());
+	m_pTextEditSource->setText(m_pFunction->sourceCode());
 
 	//--- Access privileges
 	displayACL();
@@ -223,7 +223,7 @@ void KPGFunctionPropPage::displayACL()
 	
 	// Traverse list of ACL items
 	KPGAclItemList::iterator it;
-	for ( it = m_listOfAclItems.begin(); it != m_listOfAclItems.end(); ++it )
+	for(it = m_listOfAclItems.begin(); it != m_listOfAclItems.end(); ++it)
 	{   
 		QListViewItem * pItem = new QListViewItem( m_pListViewACL, 0 );
 		(*it).setListViewItem(pItem);
@@ -238,13 +238,13 @@ void KPGFunctionPropPage::displayACL()
 	} 
 }
 
-void  KPGFunctionPropPage::displayArgumentsList()
+void KPGFunctionPropPage::displayArgumentsList()
 {
 	m_pListViewArguments->clear();
-	const KPGFunction::ListArguments & listArguments = m_pFunction->listArguments();
+    const ListFunctionArguments & listArguments = m_pFunction->listArguments();
 	
 	QListViewItem * pItemAfter = 0;
-	for(KPGFunction::ListArguments::const_iterator cit = listArguments.begin(); cit != listArguments.end(); ++cit)
+    for(ListFunctionArguments::const_iterator cit = listArguments.begin(); cit != listArguments.end(); ++cit)
 	{ 
 		
 		QListViewItem * pItem = new QListViewItem( m_pListViewArguments, pItemAfter);
@@ -257,10 +257,7 @@ void  KPGFunctionPropPage::displayArgumentsList()
 		
 		pItem->setText(0, (*cit).typName());
 		pItem->setText(1, (*cit).name());
-		
-		if((*cit).mode() == "i") pItem->setText(2, "IN");
-		else if((*cit).mode() == "o") pItem->setText(2, "OUT");
-		else if((*cit).mode() == "b") pItem->setText(2, "INOUT");
+        pItem->setText(2, (*cit).modeAsString());
 		
 		pItemAfter = pItem;
     }
