@@ -18,6 +18,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpglanguagesfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 KPGLanguagesFolderPropPage::KPGLanguagesFolderPropPage(QWidget *pParent, KPGLanguagesFolder *pLanguagesFolder)
  : KPGPropertyPage(pParent, "KPGLanguagesFolderPropPage")
@@ -44,7 +45,9 @@ void KPGLanguagesFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Language Function"));
 	pHeader->setLabel(nCol++, i18n("Language Validator"));
 
-    KPGUtil::fillPropertiesTable(m_pLanguagesFolder->resultLanguages(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pLanguagesFolder->connection()->textCodec();
+	
+    KPGUtil::fillPropertiesTable(m_pLanguagesFolder->resultLanguages(), m_pTableItems, pTextCodec);
 }
 
 
