@@ -18,6 +18,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgoperatorclassesfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 KPGOperatorClassesFolderPropPage::KPGOperatorClassesFolderPropPage(QWidget* parent, KPGOperatorClassesFolder * pOperatorClassesFolder)
 	: KPGPropertyPage(parent, "KPGOperatorClassesFolderPropPage")
@@ -43,6 +44,8 @@ void KPGOperatorClassesFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Access method"));
 	pHeader->setLabel(nCol++, i18n("Owner"));
 
-	KPGUtil::fillPropertiesTable(m_pOperatorClassesFolder->resultOperatorClasses(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pOperatorClassesFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pOperatorClassesFolder->resultOperatorClasses(), m_pTableItems, pTextCodec);
 }
 
