@@ -749,7 +749,7 @@ QWidget* KPGPropertyPageChildView::createPropertiesWidget(KPGTreeItem * pItem)
 		m_pLayout->addWidget( m_pWidgetProperties );
 		m_pWidgetProperties->show();
 				
-		connect(m_pWidgetProperties, SIGNAL(sigSearchObject(const pqxx::oid)), m_pPoGreView, SLOT( slotSearchObject(const pqxx::oid)));
+		connect(m_pWidgetProperties, SIGNAL(sigSearchObject(pqxx::oid)), m_pPoGreView, SLOT( slotSearchObject(pqxx::oid)));
 		
 		connect(m_pWidgetProperties, SIGNAL(sigTablePropContextMenuRequested(int, int, const QPoint &)), this, SLOT(slotTablePropContextMenuRequested(int, int, const QPoint &)));
 	}
