@@ -47,5 +47,7 @@ void KPGRulesFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Qualifying condition"));
 	pHeader->setLabel(nCol++, i18n("Namespace"));
 	
-	KPGUtil::fillPropertiesTable(m_pRulesFolder->resultRules(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pRulesFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pRulesFolder->resultRules(), m_pTableItems, pTextCodec);
 }
