@@ -161,8 +161,8 @@ void KPGSequencePropPage::displayIoStatistics()
     }
     catch (const KPGSqlException &e)
 	{
-	   KPGSqlDialog dlg(this, e.getSql(), e.what());
-	   dlg.exec();
+        KPGSqlDialog dlg(this, e.sql(), e.message());
+	    dlg.exec();
 	}
     
     for(int nCol = 0; nCol < 3; nCol++)
