@@ -17,7 +17,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgsequencesfolder.h"
-
+#include "../DbObjects/kpgconnection.h"
 
 KPGSequencesFolderPropPage::KPGSequencesFolderPropPage(QWidget* parent, KPGSequencesFolder * pSequencesFolder )
 	: KPGPropertyPage(parent, "KPGSequencesFolderPropPage")
@@ -42,6 +42,8 @@ void KPGSequencesFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Owner"));
 	pHeader->setLabel(nCol++, i18n("ACL"));
 	
-	KPGUtil::fillPropertiesTable(m_pSequencesFolder->resultSequences(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pSequencesFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pSequencesFolder->resultSequences(), m_pTableItems, pTextCodec);
 }
 
