@@ -32,6 +32,7 @@
 #include <kpushbutton.h>
 #include <kmessagebox.h>
 #include <klocale.h>
+#include <kdebug.h>
 
 #include "../kpgutil.h"
 #include "../kpglinklabel.h"
@@ -80,8 +81,18 @@ void KPGServerPropPage::displayProperties()
 	
 	// Display server properties
 	setVersionInfo(m_pServer->versionInfo());
-	m_ptextLabelConnectionEncoding->setText(m_pServer->connection()->clientEncoding());
 	
+    try
+    {
+        m_ptextLabelConnectionEncoding->setText(m_pServer->connection()->clientEncoding());
+    }
+    catch (const std::exception &e)
+    {
+        kdError() << k_funcinfo << e.what() << endl;
+        KMessageBox::sorry(this, m_pServer->connection()->toUnicode(e.what()));
+        return;
+    }
+    
 	//----------------------------------------------------------------------------
 	int nTableCols = KPGUtil::fillPropertiesTable(m_pServer->resultDatabases(), m_pTableDatabases, m_pServer->connection()->textCodec(), true, iColumns);
 	
@@ -146,8 +157,8 @@ void KPGServerPropPage::displayActivity()
 	}
 	catch (const KPGSqlException &e)
 	{
-	   KPGSqlDialog dlg(this, e.getSql(), e.what());
-	   dlg.exec();
+        KPGSqlDialog dlg(this, e.sql(), e.message());
+	    dlg.exec();
 	}
 }
 
