@@ -311,8 +311,8 @@ void KPGTablePropPage::displayStatistics()
     }
     catch (const KPGSqlException &e)
 	{
-	   KPGSqlDialog dlg(this, e.getSql(), e.what());
-	   dlg.exec();
+        KPGSqlDialog dlg(this, e.sql(), e.message());
+	    dlg.exec();
 	}
 }
 
@@ -383,8 +383,8 @@ void KPGTablePropPage::displayIoStatistics()
     }
     catch (const KPGSqlException &e)
 	{
-	   KPGSqlDialog dlg(this, e.getSql(), e.what());
-	   dlg.exec();
+        KPGSqlDialog dlg(this, e.sql(), e.message());
+	    dlg.exec();
 	}
 }
 
