@@ -17,6 +17,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgtablespacesfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 
 KPGTablespacesFolderPropPage::KPGTablespacesFolderPropPage(QWidget* parent, KPGTablespacesFolder * pTablespacesFolder)
@@ -53,7 +54,9 @@ void KPGTablespacesFolderPropPage::displayProperties()
   		pHeader->setLabel(nCol++, i18n("Rounded size"));
   	}
   	
-  	KPGUtil::fillPropertiesTable(m_pTablespacesFolder->resultTablespaces(), m_pTableItems, true, iColumns);
+	QTextCodec * pTextCodec = m_pTablespacesFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pTablespacesFolder->resultTablespaces(), m_pTableItems, pTextCodec, true, iColumns);
 }
 
 
