@@ -48,6 +48,8 @@ void KPGTriggersFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Namespace"));
 	pHeader->setLabel(nCol++, i18n("Procedure"));
 
-  	KPGUtil::fillPropertiesTable(m_pTriggersFolder->resultTriggers(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pTriggersFolder->connection()->textCodec();
+		
+	KPGUtil::fillPropertiesTable(m_pTriggersFolder->resultTriggers(), m_pTableItems, pTextCodec);
 }
 
