@@ -50,7 +50,7 @@ protected slots:
 	virtual void slotTablePropContextMenuRequested(int, int, const QPoint &);    
 		
 signals:
-  	void sigSearchObject(const pqxx::oid);   
+  	void sigSearchObject(pqxx::oid);   
    	            
     // Emit request for context menu for property table
 	void sigTablePropContextMenuRequested(int, int, const QPoint &);
