@@ -17,6 +17,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgviewsfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 
 KPGViewsFolderPropPage::KPGViewsFolderPropPage(QWidget* parent, KPGViewsFolder * pViewsFolder)
@@ -43,7 +44,9 @@ void KPGViewsFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Owner"));
   	pHeader->setLabel(nCol++, i18n("ACL"));
 
-	KPGUtil::fillPropertiesTable(m_pViewsFolder->resultViews(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pViewsFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pViewsFolder->resultViews(), m_pTableItems, pTextCodec);
 }
 
 
