@@ -51,7 +51,7 @@
 #include "kpgsqlparser.h"
 
 #define NUM_OF_RECORDS_PER_PAGE 500 // How many records are loaded to result table 
-#define UPDATE_TIMER_INTERVAL 1000 // 1 sec for updatiing code completion
+#define UPDATE_TIMER_INTERVAL 1000 // 1 sec for updating code completion
 
 KPGQueryResultWindow::KPGQueryResultWindow(KPGQueryResultChildView *parent, 
 	KPoGreView *pPoGreView,
@@ -66,11 +66,12 @@ KPGQueryResultWindow::KPGQueryResultWindow(KPGQueryResultChildView *parent,
  	m_pPoGreView(pPoGreView),
 	m_bCodeCompletionListUpdated(true),
 	m_pUpdateCodeCompletionListTimer(0),
-	m_pFind(0)
+    m_pFind(0),
+    m_pXmlGuiFactory(pXmlGuiFactory)
 {
 	// Setup GUI
+    //setFactory(pXmlGuiFactory);
 	setXMLFile("kpgqueryreslt.rc", true);
-	m_pXmlGuiFactory = pXmlGuiFactory;
 	m_bIsAddedToGuiFactory = false;
 
 	// Setup tab icons
@@ -93,12 +94,7 @@ KPGQueryResultWindow::KPGQueryResultWindow(KPGQueryResultChildView *parent,
 	m_pActFindNextInResult = new KAction(i18n("Find next in result"), "next", 0, this, SLOT(slotFindNextInResult()), actionCollection(), "edit_find_next_in_result");
 	m_pActFindNextInResult->setWhatsThis(i18n("Find next in result table."));
     
-	m_pActRunQuery->setEnabled(false);
-	m_pActStopQuery->setEnabled(false);
-	m_pActFetchNext->setEnabled(false);
-  	m_pActFetchAll->setEnabled(false);
-  	
-  	//-----------------------------------------------------------------
+	//-----------------------------------------------------------------
 	// Common clipboard actions
 	m_pActCopyCell = new KAction(i18n("&Copy cell"), "editcopy", 0, this, SLOT(slotCopyCell()), actionCollection(), "copy_cell");
 	
@@ -108,6 +104,21 @@ KPGQueryResultWindow::KPGQueryResultWindow(KPGQueryResultChildView *parent,
 	
 	m_pActCopyTableXml = new KAction(i18n("Copy table to &XML"), 0, 0, this, SLOT(slotCopyTableXml()), actionCollection(), "copy_table_xml");
 	
+    //-----------------------------------------------------------------
+    // Initial actions state 
+    m_pActRunQuery->setEnabled(false);
+    m_pActStopQuery->setEnabled(false);
+    m_pActFetchNext->setEnabled(false);
+    m_pActFetchAll->setEnabled(false);
+    
+    m_pActFindInResult->setEnabled(false);
+    m_pActFindNextInResult->setEnabled(false);
+    
+    m_pActCopyCell->setEnabled(false);
+    m_pActCopyRow->setEnabled(false);
+    m_pActCopyTableCsv->setEnabled(false);
+    m_pActCopyTableXml->setEnabled(false);
+    
 	//-----------------------------------------------------------------
 	// Create Kate part editor
     m_pKateView = createKatePart(pKatePartFactory);
@@ -214,18 +225,20 @@ void KPGQueryResultWindow::addToGuiFactory()
 {
 	if(m_pKateView && !m_bIsAddedToGuiFactory)
     {
+        //setFactory(m_pXmlGuiFactory);
         m_pXmlGuiFactory->addClient(this);
         m_pXmlGuiFactory->addClient(m_pKateView);
         m_bIsAddedToGuiFactory = true;
         m_pKateView->setFocus();
     }
 }
-    
+
 // Remove yourself and Kate view from GUI factory
 void KPGQueryResultWindow::removeFromGuiFactory()
 {
     if(m_pKateView && m_bIsAddedToGuiFactory)
     {
+        //setFactory(m_pXmlGuiFactory);
         m_pXmlGuiFactory->removeClient(this);
         m_pXmlGuiFactory->removeClient(m_pKateView);
         m_bIsAddedToGuiFactory = false;
@@ -251,7 +264,7 @@ Kate::View* KPGQueryResultWindow::createKatePart(KParts::Factory* pFactory)
 // Display popup menu
 void KPGQueryResultWindow::slotContextMenuRequested(int, int, const QPoint &pos)
 {
-	QWidget * pContainer = m_pXmlGuiFactory->container("popupQueryResultTable", this);
+    QWidget * pContainer = factory()->container("popupQueryResultTable", this);
 
 	if ( ! pContainer )
 	{
@@ -539,6 +552,8 @@ void KPGQueryResultWindow::runQuery(KPGDatabase *pDatabase)
 	
 	// free memory
 	m_pqxxResult.clear(); 
+    m_nTotalRows = 0;
+    m_nTotalCols = 0;
 		
 	int iTransType = m_pComboBoxTransaction->currentItem();
 	KPGConnection::ETransType transType = KPGConnection::eTransNormal;
@@ -567,13 +582,18 @@ void KPGQueryResultWindow::runQuery(KPGDatabase *pDatabase)
 	m_pActStopQuery->setEnabled(true);
 	m_pActFetchNext->setEnabled(false);
   	m_pActFetchAll->setEnabled(false);
-  	m_pActFindInResult->setEnabled(false); 
+  	m_pActFindInResult->setEnabled(false);
+    
+    m_pActCopyCell->setEnabled(false);
+    m_pActCopyRow->setEnabled(false);
+    m_pActCopyTableCsv->setEnabled(false);
+    m_pActCopyTableXml->setEnabled(false);
     	
 	try
 	{
 		m_connectionInThread.connectToServer(pDatabase->connection()->options());
 		KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
-		connect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+        connect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 		
 	}
 	catch (const std::exception &e)
@@ -605,6 +625,8 @@ void KPGQueryResultWindow::runQuery(KPGDatabase *pDatabase)
 
 void KPGQueryResultWindow::customEvent(QCustomEvent *pEvent)
 {
+	m_connectionInThread.wait();
+	
 	KPGQueryResultEvent *pQueryResultEvent = static_cast <KPGQueryResultEvent *> (pEvent);
 	
 	//kdDebug() << QString("Result size is: %1").arg(m_pqxxResult.size()) << endl;
@@ -688,10 +710,8 @@ void KPGQueryResultWindow::customEvent(QCustomEvent *pEvent)
 	emit sigSetTerminalIcon(this, 2); // blue terminal icon
 	((QWidget *) parent())->setCursor(KCursor::arrowCursor());
 	
-	m_connectionInThread.wait();
-	
 	KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
-	disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+    disconnect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 	
 	m_connectionInThread.disconnectFromServer(); // close connection
 		
@@ -699,7 +719,14 @@ void KPGQueryResultWindow::customEvent(QCustomEvent *pEvent)
 	m_pActStopQuery->setEnabled(false);
 	m_pActFetchNext->setEnabled((fetchedAllRows()) ? false : true);
   	m_pActFetchAll->setEnabled((fetchedAllRows()) ? false : true);
-  	m_pActFindInResult->setEnabled((resultEmpty()) ?  false : true);
+    
+    bool bResultNotEmpty = !resultEmpty();
+    
+    m_pActFindInResult->setEnabled(bResultNotEmpty);
+    m_pActCopyCell->setEnabled(bResultNotEmpty);
+    m_pActCopyRow->setEnabled(bResultNotEmpty);
+    m_pActCopyTableCsv->setEnabled(bResultNotEmpty);
+    m_pActCopyTableXml->setEnabled(bResultNotEmpty);
 }
 
 void KPGQueryResultWindow::stopQuery()
@@ -710,7 +737,7 @@ void KPGQueryResultWindow::stopQuery()
 		m_connectionInThread.wait();
 		
 		KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
-		disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+        disconnect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 		
 		m_connectionInThread.leaveConnection();
 		
@@ -1018,10 +1045,13 @@ void KPGQueryResultWindow::slotFindInResultNext()
 		}
 
     if( res == KFind::NoMatch ) 
-    { // i.e. at end
+    { 
+        // i.e. at end
+        m_pFind->closeFindNextDialog();
         m_pFind->displayFinalDialog();
         m_pFind->resetCounts();
         m_pTableResult->removeSelection(0);
+        m_pActFindNextInResult->setEnabled(false);
     }
 }
 
@@ -1030,10 +1060,11 @@ void KPGQueryResultWindow::slotHighlight( const QString &, int, int)
 {
     //kdDebug() << "highlight: " << index << " " << length << endl;
     m_pTableResult->setCurrentCell(m_iRowToSearch, m_iColToSearch);
+    m_pActFindNextInResult->setEnabled(true);
 }
 
 // Process notice from connection in thread
-void KPGQueryResultWindow::slotProcessNotice(QString strNotice)
+void KPGQueryResultWindow::slotProcessNotice(const QString & strNotice)
 {
 	qApp->lock();
 	m_pTextEditResult->append(strNotice);
@@ -1475,6 +1506,11 @@ void KPGQueryResultWindow::insertSnippet(const QString & strText)
 	m_pKateView->setFocus();
 }
 
+void KPGQueryResultWindow::virtual_hook(int id, void* data)
+{ 
+    KXMLGUIClient::virtual_hook(id, data); 
+}
+
 // Scan for possible completions, ignoring any dublets
 /*QValueList<KTextEditor::CompletionEntry> KPGQueryResultWindow::allMatches(const QString &word)
 {
