@@ -14,23 +14,25 @@
 
 #include <qwidget.h>
 #include <qstring.h>
+#include <qstrlist.h>
 
 #include <kurl.h>
 
 /**
-Widget that display Konsole using KParts
-
-@author Lumir Vanek
-*/
-
-
-namespace KParts {
+  * Widget that display Konsole using KParts
+  *
+  * @author Lumir Vanek
+  */
+namespace KParts 
+{
   class ReadOnlyPart;
   class Part;
   class PartManager; 
 }
-class QVBoxLayout;
 
+class QVBoxLayout;
+class ExtTerminalInterface;
+class KProcess;
 
 class KonsoleViewWidget : public QWidget
 {
@@ -41,17 +43,25 @@ public:
 
     virtual void show();
     
+    void startProgram(const QString &, const QStrList &);
+    
 public slots:
     void setDirectory(const KURL &dirUrl);
     void activePartChanged(KParts::Part *activatedPart);
         
-private slots:
-    void partDestroyed();
+protected slots:
+    void slotProcessExited(KProcess *);
+    void slotPartDestroyed();
         
+signals:     
+    void sigProcessExited();
+    
 private:
     void activate();
 
-    KParts::ReadOnlyPart *part;
+    KParts::ReadOnlyPart *m_pConcolePart;
+    ExtTerminalInterface *m_pTerminalInterface;
+    
     QVBoxLayout *vbox;
     KParts::PartManager *m_pPartManager;
 };
