@@ -54,7 +54,7 @@ private:
 	
 protected slots:
 	// Process notice from connection in thread
-	void slotProcessNotice(QString);
+    void slotProcessNotice(const QString &);
 };
 
 #endif
