@@ -61,7 +61,7 @@ protected slots:
 	void slotEnableNextButton1(bool);
 	
 	// Process notice from connection
-	void slotProcessNotice(QString);
+    void slotProcessNotice(const QString &);
 };
 
 #endif
