@@ -68,7 +68,7 @@ protected slots:
 	void slotEnableNextButton2(bool);
 	
 	// Process notice from connection
-	void slotProcessNotice(QString);
+	void slotProcessNotice(const QString &);
 };
 
 #endif
