@@ -73,7 +73,7 @@ protected slots:
     void slotEnableNextButton3(bool);
 		
 	// Process notice from connection
-	void slotProcessNotice(QString);
+    void slotProcessNotice(const QString &);
 };
 
 #endif
