@@ -78,7 +78,7 @@ protected slots:
 	void slotEnableNextButton4(bool);
 			
 	// Process notice from connection
-	void slotProcessNotice(QString);
+    void slotProcessNotice(const QString &);
 };
 
 #endif
