@@ -82,7 +82,7 @@ protected slots:
 	void slotEnableNextButton5(bool);
 			
 	// Process notice from connection
-	void slotProcessNotice(QString);
+    void slotProcessNotice(const QString &);
 };
 
 #endif
