@@ -623,13 +623,8 @@ const QString KPGCreateFunctionWidget2::getFuncParams() const
 // Return part of SQL statement for CREATE FUNCTION
 const QString KPGCreateFunctionWidget2::getSQL() const
 {
-    QString strSQL("");
-	
-    if(m_pCheckBoxWithoutReturn->isChecked() == true)
-        return strSQL;
-    
-    strSQL.append("\n");
-    
+    QString strSQL("\n");
+	    
     // return type
     QString strReturnType(m_pComboBoxReturnType->currentText());
     QString strNamespace(m_pComboBoxRetTypeSchema->currentText());
@@ -667,7 +662,16 @@ const QString KPGCreateFunctionWidget2::getSQL() const
     }
     
     strSQL.append("RETURNS ");
-    if(m_pCheckBoxReturnSet->isChecked()) strSQL.append("SETOF ");
+    if(m_pCheckBoxWithoutReturn->isChecked())
+    {
+        strSQL.append("void\n");
+        return strSQL;
+    }
+    else
+    {
+        if(m_pCheckBoxReturnSet->isChecked()) 
+            strSQL.append("SETOF ");
+    }
     strSQL.append(strDefinition);
     strSQL.append("\n");
 	  
