@@ -14,20 +14,21 @@
 
 #include "kpgdumpdatabasewizardbase.h"
 
-#include <kparts/partmanager.h>
 #include <qguardedptr.h>
+#include <qstrlist.h>
 
-#include "../kpgdcoptalkthread.h"
+#include <kparts/partmanager.h>
+
+//#include "../kpgdcoptalkthread.h"
 
 class KonsoleViewWidget;
 class DCOPClient;
 
 /**
-DUMP database wizard
-
-@author Lumir Vanek
-*/
-
+  * DUMP database wizard
+  *
+  * @author Lumir Vanek
+  */
 class KPGDumpDatabaseWizard : public KPGDumpDatabaseWizardBase
 {
 Q_OBJECT
@@ -41,7 +42,7 @@ protected:
     KParts::PartManager *m_pPartManager;
     DCOPClient *m_pDcopClient;
     QGuardedPtr<KonsoleViewWidget> m_pConsoleWidget;
-    KPGDcopTalkThread m_dcopTalkThread;
+    //KPGDcopTalkThread m_dcopTalkThread;
     
 protected slots:
     virtual void slotOutputFileChanged(const QString &);
@@ -49,9 +50,11 @@ protected slots:
     virtual void slotOnlyDataToggled(bool);
     virtual void slotOnlySchemaToggled(bool);
     
+    void slotProcessExited();
+    
 protected:
     virtual void showPage(QWidget *);
-    const QString getCommand() const;
+    QStrList getDumpArguments() const;
     
     QString m_strDatabase;
     QString m_strHostname;
