@@ -14,25 +14,27 @@
 
 #include "kpgrestoredatabasewizardbase.h"
 
-#include <kparts/partmanager.h>
 #include <qguardedptr.h>
+#include <qstrlist.h>
 
-#include "../kpgdcoptalkthread.h"
+#include <kparts/partmanager.h>
+
+
+//#include "../kpgdcoptalkthread.h"
 
 class KonsoleViewWidget;
 class DCOPClient;
 
 /**
-Restore database Wizard
-
-@author Lumir Vanek
-*/
-
+  * Restore database Wizard
+  *
+  * @author Lumir Vanek
+  */
 class KPGRestoreDatabaseWizard : public KPGRestoreDatabaseWizardBase
 {
 Q_OBJECT
 public:
-    KPGRestoreDatabaseWizard(QWidget *parent, const char *name, DCOPClient *, const QString &, const QString &, const QString &, const QString &);
+    KPGRestoreDatabaseWizard(QWidget *parent, const char *name, DCOPClient *, const QString &, const QString &, const QString &, const QString &, bool);
     ~KPGRestoreDatabaseWizard();
 
     KParts::PartManager * partManager() const { return m_pPartManager; }
@@ -41,21 +43,25 @@ protected:
     KParts::PartManager *m_pPartManager;
     DCOPClient *m_pDcopClient;
     QGuardedPtr<KonsoleViewWidget> m_pConsoleWidget;
-    KPGDcopTalkThread m_dcopTalkThread;
+    //KPGDcopTalkThread m_dcopTalkThread;
     
 protected slots:
     virtual void slotInputFileChanged(const QString &);
     virtual void slotOnlyDataToggled(bool);
     virtual void slotOnlySchemaToggled(bool);
     
+    void slotProcessExited();
+    
 protected:
     virtual void showPage(QWidget *);
-    const QString getCommand() const;
+    QStrList getRestoreArguments() const;
     
     QString m_strDatabase;
     QString m_strHostname;
     QString m_strPort;
     QString m_strUsername;
+    
+    bool m_bCreateFromDump;
 };
 
 #endif
