@@ -17,14 +17,13 @@
 class KPGUsersFolder;
 
 /**
-Set owner Wizard
-
-@author Lumir Vanek
-*/
-
+  * Set owner Wizard
+  *
+  * @author Lumir Vanek
+  */
 class KPGSetOwnerWizard : public KPG3StepsWizard
 {
-Q_OBJECT
+	Q_OBJECT
 public:
     KPGSetOwnerWizard(QWidget *parent, const char *name, KPGUsersFolder *, const char *, const QString &, const QString &);
     ~KPGSetOwnerWizard();
