@@ -17,11 +17,10 @@
 class KPGTablespacesFolder;
 
 /**
-Set tablespace Wizard
-
-@author Lumir Vanek
-*/
-
+  * Set tablespace Wizard
+  *
+  * @author Lumir Vanek
+  */
 class KPGSetTablespaceWizard : public KPG3StepsWizard
 {
 Q_OBJECT
@@ -33,8 +32,8 @@ protected:
     virtual void showPage(QWidget *);
 
 protected:
-  QString m_strObjectTypeName; // TABLE, INDEX ...
-  QString m_strNamespaceObjectName; // schema qualified object name
+  	QString m_strObjectTypeName; // TABLE, INDEX ...
+  	QString m_strNamespaceObjectName; // schema qualified object name
       
 protected slots:
     virtual void languageChange(); 
