@@ -17,11 +17,12 @@
 class DCOPClient;
 
 /**
-Thread that talk with Console part via DCOP
-
-@author Lumir Vanek
-*/
-
+  *
+  * Thread that talk with Console part via DCOP
+  *
+  * @author Lumir Vanek
+  * @deprecated L.V. 25.3.2009 Now, backup/restore wizards uses ExtTerminalInterface, rather than unreliable DCOP
+  */
 class KPGDcopTalkThread : public QThread
 {
 public:
