@@ -35,7 +35,7 @@ public:
 	void setValues(pqxx::oid, const QString &);
 
 	// Return PostgreSQL row identifier
-	const pqxx::oid oid() const { return m_oid; }
+	pqxx::oid oid() const { return m_oid; }
 		
 //public slots:
 //   virtual void openLink(const QString &);
