@@ -19,6 +19,7 @@
 
 //class QStringList;
 class QString;
+class QTextCodec;
 
 using namespace pqxx;
 
@@ -33,17 +34,18 @@ class KPGNoticer : public QObject,  public noticer
 	Q_OBJECT
 	
 public:	
-	KPGNoticer(/*QStringList * */);
+	KPGNoticer(QTextCodec *);
 	virtual ~KPGNoticer() throw ();
 	
 	virtual void operator()(const char Msg[]) throw ();
 	
-	// List of collected notifications
-	//QStringList *m_pListOfNotifications;
+private:
+	// Codec for encode/decode strings from/to database
+	QTextCodec *m_pTextCodec;
 	
 signals:
 	// Emit notice
-	void sigNotice(QString);
+    void sigNotice(const QString &);
 };
 
 #endif
