@@ -17,20 +17,24 @@
 // include files for Qt
 #include <qstring.h>
 
+class KPGConnection;
+
 /**
   * SQL Exception, contain info about SQL statement, that cause it
   *
   *	@author Lumir Vanek <lvanek@users.sourceforge.net>
   */
-class KPGSqlException : public std::runtime_error
+class KPGSqlException //: public std::runtime_error
 {
 public:
-    KPGSqlException(const char*, const QString &);
+    KPGSqlException(KPGConnection *, const char *, const QString &);
     ~KPGSqlException() throw() {;}
 
-    const QString & getSql() const { return m_strSql; }
+    const QString & sql() const { return m_strSql; }
+    const QString & message() const { return m_strMessage; }
+    
 protected:
-
+    QString m_strMessage;
     QString m_strSql;
 };
 
