@@ -21,6 +21,7 @@
 
 // Forward references
 class QTable;
+class QTextCodec;
 class KComboBox;
 class KPGDatabase;
 
@@ -40,9 +41,9 @@ public:
 	static const QString unquotedName(const QString &);
 	static const QString unspacedName(const QString &);
 	static const QString fullyQualifiedName(const QString &, const QString &);
-	static const bool containsUpperCase(const QString &);
+	static bool containsUpperCase(const QString &);
 	
-	static int fillPropertiesTable(const pqxx::result &, QTable *, bool = true, int = -1);
+	static int fillPropertiesTable(const pqxx::result &, QTable *, QTextCodec *, bool = true, int = -1);
 	static void fillComboBoxWithDatabaseSchemas(KPGDatabase *, KComboBox *, bool = false);
 
 	//--- Common clibpoard action handling
