@@ -160,7 +160,9 @@ void KPoGreController::initActions(KActionCollection * pActionCollection)
 	
 	//--- Database related menu actions
 	
-	(void) new KAction( i18n("&Create database..."), "wizard", 0, this, SLOT(slotCreateDatabase()), pActionCollection, "create_database" );
+	(void) new KAction( i18n("&Create new database..."), "wizard", 0, this, SLOT(slotCreateDatabase()), pActionCollection, "create_database" );
+    
+    (void) new KAction( i18n("&Create database from dump..."), "revert", 0, this, SLOT(slotLoadDatabase()), pActionCollection, "load_database" );
 	
 	(void) new KAction( i18n("&Drop database..."), "editdelete", 0, this, SLOT(slotDropDatabase()), pActionCollection, "drop_database" );
  
@@ -789,6 +791,14 @@ void KPoGreController::slotCreateDatabase()
     slotStatusMsg(i18n("Ready."));
 }
 
+// Run Create Database Wizard 
+void KPoGreController::slotLoadDatabase()
+{
+    slotStatusMsg(i18n("Create database from dump..."));
+    m_pView->loadDatabase();
+    slotStatusMsg(i18n("Ready."));
+}
+
 // Run Drop Database Wizard 
 void KPoGreController::slotDropDatabase()
 {
