@@ -309,7 +309,8 @@ public:
 	
     //--- Database related menu actions
   	void createDatabase();
-	void dropDatabase();
+    void loadDatabase();
+    void dropDatabase();
 	void analyseDatabase();
 	void reindexDatabase();
 	void setOwnerDatabase();
@@ -515,7 +516,7 @@ protected slots:
 	void slotRequestFunctionReturnTypeAttributesListsForCodeCompletion(KPGQueryResultWindow *, const KPGOidNameAliases *);
 		
 	// Called from property pages when user double-clicks on KPGLinkLabel
-	void slotSearchObject(const pqxx::oid);
+	void slotSearchObject(pqxx::oid);
   
   	// Callen when property page need run Wizard
   	void slotRunWizard(const QString &);
